Learn R Programming

bhmbasket (version 1.0.0)

setPriorParametersBerry: setPriorParametersBerry

Description

This function sets prior parameters for the analysis method "berry" for use in performAnalyses.

Usage

setPriorParametersBerry(mu_mean, mu_sd, tau_scale)

Value

A list with prior parameters of class prior_parameters_list

Arguments

mu_mean

A numeric for the mean of \(\mu\)

mu_sd

A positive numeric for the standard deviation of \(\mu\)

tau_scale

A positive numeric for the scale parameter of \(\tau\)

Author

Stephan Wojciekowski

Details

This function sets the prior parameters for the method proposed by Berry et al. (2013). Note that the implemented distribution of \(\tau\) is half-normal.

References

Berry, Scott M., et al. "Bayesian hierarchical modeling of patient subpopulations: efficient designs of phase II oncology clinical trials." Clinical Trials 10.5 (2013): 720-734.

See Also

performAnalyses getPriorParameters combinePriorParameters setPriorParametersExNex setPriorParametersExNexAdj setPriorParametersPooled setPriorParametersStratified getMuVar

Examples

Run this code
 prior_parameters_berry <- setPriorParametersBerry(0, 1, 2)

Run the code above in your browser using DataLab