Learn R Programming

bhmbasket (version 1.0.0)

setPriorParametersExNex: setPriorParametersExNex

Description

This function sets prior parameters for the analysis method "exnex" for use in performAnalyses.

Usage

setPriorParametersExNex(mu_mean, mu_sd, tau_scale, mu_j, tau_j, w_j)

Value

A list with prior parameters of class prior_parameters_list

Arguments

mu_mean

A numeric for the mean of \(\mu\)

mu_sd

A positive numeric for the standard deviation of \(\mu\)

tau_scale

A positive numeric for the scale parameter of \(\tau\)

mu_j

A vector of numerics for the means \(\mu_j\)

tau_j

A vector of positive numerics for the standard deviations \(\tau_j\)

w_j

A numeric in (0, 1) for the weight of the Ex component

Author

Stephan Wojciekowski

Details

This function sets the prior parameters for the method proposed by Neuenschwander et al. (2016).

References

Neuenschwander, Beat, et al. "Robust exchangeability designs for early phase clinical trials with multiple strata." Pharmaceutical statistics 15.2 (2016): 123-134.

See Also

performAnalyses getPriorParameters combinePriorParameters setPriorParametersBerry setPriorParametersExNexAdj setPriorParametersPooled setPriorParametersStratified getMuVar

Examples

Run this code
 prior_parameters_exnex <- setPriorParametersExNex(0, 1, 2, c(4, 5), c(6, 7), 0.8)

Run the code above in your browser using DataLab