Learn R Programming

bhmbasket (version 1.0.0)

setPriorParametersPooled: setPriorParametersPooled

Description

This function sets prior parameters for the analysis method "pooled" for use in performAnalyses.

Usage

setPriorParametersPooled(a, b)

Value

A list with prior parameters of class prior_parameters_list

Arguments

a

A positive numeric for \(\alpha\)

b

A positive numeric for \(\beta\)

Author

Stephan Wojciekowski

Details

The method "pooled" is a beta-binomial model that pools all cohorts. The prior parameters are the scale parameters of the beta prior distribution.

See Also

performAnalyses getPriorParameters combinePriorParameters setPriorParametersBerry setPriorParametersExNex setPriorParametersExNexAdj setPriorParametersStratified getMuVar

Examples

Run this code
 prior_parameters_pooled <- setPriorParametersPooled(1, 2)

Run the code above in your browser using DataLab