This function creates an object of class scenario_list
for a single trial outcome, which can subsequently be analyzed with other functions of
bhmbasket, e.g. performAnalyses
Usage
createTrial(n_subjects, n_responders)
Value
An object of class scenario_list with the scenario data for a single trial outcome.
Arguments
n_subjects
A vector of integers for the number of subjects in the trial outcome
n_responders
A vector of integers for the number of responders in the trial outcome
Author
Stephan Wojciekowski
Details
This function is a wrapper for simulateScenarios with