A list with prior parameters of class prior_parameters_list
Arguments
mu_mean
A numeric for the mean of \(\mu\)
mu_sd
A positive numeric for the standard deviation of \(\mu\)
tau_scale
A positive numeric for the scale parameter of \(\tau\)
Author
Stephan Wojciekowski
Details
This function sets the prior parameters for the method proposed by Berry et al. (2013).
Note that the implemented distribution of \(\tau\) is half-normal.
References
Berry, Scott M., et al. "Bayesian hierarchical modeling of patient subpopulations:
efficient designs of phase II oncology clinical trials."
Clinical Trials 10.5 (2013): 720-734.