A list with prior parameters of class prior_parameters_list
Arguments
mu_mean
A numeric for the mean of \(\mu\)
mu_sd
A positive numeric for the standard deviation of \(\mu\)
tau_scale
A positive numeric for the scale parameter of \(\tau\)
mu_j
A vector of numerics for the means \(\mu_j\)
tau_j
A vector of positive numerics for the standard deviations \(\tau_j\)
w_j
A numeric in (0, 1) for the weight of the Ex component
Author
Stephan Wojciekowski
Details
This function sets the prior parameters for the method ExNex Adjusted, which combines
the approach proposed by Neuenschwander et al. (2016) and the approach proposed by
Berry et al. (2013).